/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef LOGGER_DIALOG_H
#define LOGGER_DIALOG_H


#include <tqmap.h>
#include <tqpixmap.h>


#include "loggerDialogBase.h"

class LoggerDialog: public LoggerDialogBase {
	TQ_OBJECT
  
	public:
		LoggerDialog(TQWidget *parent = 0, const char *name = 0);
	
	protected slots:
		void sendMessage();
		
		void textChanged(const TQString&);
		
		void tagActivationChanged(bool activation);
		void fileActivationChanged(bool activation);
		void messageActivationChanged(bool activation);
		
	protected:
		void buildMaps();
		
		TQMap<TQString, TQString> facilities;
		
		TQMap<TQString, TQString> priorities;
		TQMap<TQString, TQPixmap> priorityIcons;

};

#endif
